==> klaude_code-0.1.0.tar.gz: klaude_code-0.1.0/src/klaudecode/tools/exit_plan_mode.py <==
from typing import Annotated

from pydantic import BaseModel, Field
from rich.padding import Padding
from rich.panel import Panel
from rich.text import Text

from ..message import ToolCall, ToolMessage, register_tool_call_renderer, register_tool_result_renderer
from ..prompt.plan_mode import APPROVE_HINT, EXIT_PLAN_MODE_TOOL_DESC, EXIT_PLAN_MODE_TOOL_PLAN_ARG_DESC, REJECT_HINT
from ..tool import Tool, ToolInstance
from ..tui import ColorStyle, render_markdown, render_suffix


class ExitPlanModeTool(Tool):
    name = 'ExitPlanMode'
    description = EXIT_PLAN_MODE_TOOL_DESC
    parallelable: bool = False

    class Input(BaseModel):
        plan: Annotated[str, Field(description=EXIT_PLAN_MODE_TOOL_PLAN_ARG_DESC)]

    @classmethod
    def skip_in_tool_handler(cls) -> bool:
        return True

    @classmethod
    def invoke(cls, tool_call: ToolCall, instance: 'ToolInstance'):
        # This should never be called as the tool is intercepted in agent.py
        pass


def render_exit_plan_mode_args(tool_call: ToolCall):
    yield Text(tool_call.tool_name, 'bold')
    yield "Here is Claude's plan:"
    yield Padding.indent(
        Panel.fit(render_markdown(tool_call.tool_args_dict['plan']), border_style=ColorStyle.AGENT_BORDER),
        level=2,
    )


def render_exit_plan_mode_content(tool_msg: ToolMessage):
    approved = tool_msg.get_extra_data('approved', False)
    yield render_suffix(APPROVE_HINT if approved else REJECT_HINT, style=ColorStyle.SUCCESS.value if approved else ColorStyle.ERROR.value)


register_tool_call_renderer('ExitPlanMode', render_exit_plan_mode_args)
register_tool_result_renderer('ExitPlanMode', render_exit_plan_mode_content)

==> klaude_code-0.1.11.tar.gz: klaude_code-0.1.11/src/klaudecode/tools/exit_plan_mode.py <==
from typing import Annotated

from pydantic import BaseModel, Field
from rich.padding import Padding
from rich.panel import Panel
from rich.text import Text

from ..message import ToolCall, ToolMessage, register_tool_call_renderer, register_tool_result_renderer
from ..prompt.plan_mode import APPROVE_HINT, EXIT_PLAN_MODE_TOOL_DESC, EXIT_PLAN_MODE_TOOL_PLAN_ARG_DESC, REJECT_HINT
from ..tool import Tool, ToolInstance
from ..tui import ColorStyle, render_markdown, render_suffix

"""
- Interactive plan approval workflow with rich UI rendering
- Markdown-formatted plan display with syntax highlighting
- User approval/rejection handling and visual feedback
- Special tool handler bypass for agent-level interception
"""


class ExitPlanModeTool(Tool):
    name = 'ExitPlanMode'
    desc = EXIT_PLAN_MODE_TOOL_DESC
    parallelable: bool = False

    class Input(BaseModel):
        plan: Annotated[str, Field(description=EXIT_PLAN_MODE_TOOL_PLAN_ARG_DESC)]

    @classmethod
    def skip_in_tool_handler(cls) -> bool:
        return True

    @classmethod
    def invoke(cls, tool_call: ToolCall, instance: 'ToolInstance'):
        # This should never be called as the tool is intercepted in agent.py
        pass


def render_exit_plan_mode_args(tool_call: ToolCall, is_suffix: bool = False):
    yield Text("Here is Claude's plan:", ColorStyle.TOOL_NAME.bold)
    yield Padding.indent(
        Panel.fit(render_markdown(tool_call.tool_args_dict['plan']), border_style=ColorStyle.LINE),
        level=2,
    )


def render_exit_plan_mode_content(tool_msg: ToolMessage):
    approved = tool_msg.get_extra_data('approved', False)
    yield render_suffix(APPROVE_HINT if approved else REJECT_HINT, style=ColorStyle.SUCCESS if approved else ColorStyle.ERROR)


register_tool_call_renderer('ExitPlanMode', render_exit_plan_mode_args)
register_tool_result_renderer('ExitPlanMode', render_exit_plan_mode_content)
